
# ToDos

* Add optional argument to `get_company` to specify the exchange
* Add ability to retrieve advanced transcript data
* Raise helpful error if the user tries to make a call that the current plan doesn't support
* Add streaming support for Audio Data.
* Verify changing API keys invalidates the cache


# Considerations

* Consider removing all debug logging.
* Consider implementing @dataclass and @dataclass_json from scratch to avoid third-party dependency
